@@ -1,6 +1,6 @@
 package Getopt::EX::Module;
 
-our $VERSION = "3.00";
+our $VERSION = "3.01";
 
 use v5.14;
 use warnings;
@@ -33,7 +33,7 @@ sub new {
 	Help => [],
     }, $class;
 
-    configure $obj @_ if @_;
+    $obj->configure(@_) if @_;
 
     $obj;
 }
